<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:param name="showhidden" />

<!-- How to use printcomps.xsl -->
<!--
1. Copy install_media/*/base/comps.xml to the same directory as that you extracted printcomps.xsl and printcomps.xsl to.
2. Edit comps.xml - comment out or delete the line (near the top) that looks:
  <!DOCTYPE comps PUBLIC "-//Red Hat, Inc.//DTD Comps info//EN" "comps.dtd">
3. Open printcomps.html by XML capable browser. These XSL and HTML were tested on IE 6.01 and Mozilla FireFox.
That's all. Enjoy.
-->
<!--
By default, printcomps shows GROUP DESCRIPTIONs that match browser's primary language. If you, for some reason, want printcomps to show them in a specific language, insert your preferable lang-code between <xsl:param name="lang"> and </xsl:param> below. A glimpse of comps.XML will tell you valid lang-codes.
-->
<xsl:param name="lang"></xsl:param>

<xsl:output
  method="html"
  encoding="UTF-8"
  doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" />

<!-- Main procedure -->
<xsl:template match="/comps">
  <xsl:if test="./sample!=''">
    <h2 style="color:red"><xsl:value-of select="./sample" /></h2>
  </xsl:if>
  <h2>CATEGORY HIERARCHY</h2>
  <xsl:apply-templates select="./grouphierarchy" />
  <hr />
  <h2>GROUPS and METAPACKAGES</h2>
  <xsl:apply-templates select="group" />
</xsl:template>

<!-- Content of each GROUP -->
<xsl:template name="grpcontent">
  <a><xsl:attribute name="name"><xsl:value-of select="id" /></xsl:attribute></a>
  <h3><xsl:value-of select="id" /> 　<a href="#">†</a></h3>
  <dl>
  <dd><b>NAME: </b><xsl:value-of select="name" /></dd>
  <xsl:if test="description!=''">
    <dd><b>DESCRIPTION: </b><xsl:value-of select="description" /></dd>
    <dd><b>DESCRIPTION[<xsl:value-of select="$lang" />]: </b><xsl:value-of select="description[lang($lang)]" /></dd>
  </xsl:if>
  <dd><b>DEFAULT?: </b><xsl:value-of select="default" /> 　<b>USERVISIBLE： </b><xsl:value-of select="uservisible" /></dd>
  <xsl:if test="grouplist/groupreq">
    <dd><b>__ GROUPS ___________________________</b></dd>
    <dd><ul>
      <xsl:apply-templates select="grouplist/groupreq" />
    </ul></dd>
  </xsl:if>
  <xsl:if test="grouplist/metapkg">
    <dd><b>__ METAPKGS ________________________</b></dd>
    <dd><ul>
      <xsl:apply-templates select="grouplist/metapkg" />
    </ul></dd>
  </xsl:if>
  <xsl:if test="packagelist/packagereq">
    <dd><b>__ PACKAGES ________________________</b></dd>
    <dd><ul>
      <xsl:apply-templates select="packagelist/packagereq" />
    </ul></dd>
  </xsl:if>
  </dl>
</xsl:template>

<!-- Generation of GROUP and METAPKG list element -->
<xsl:template name="ligen">
  <xsl:param name="ty" />
  <li><xsl:attribute name="id"><xsl:value-of select="$ty" /></xsl:attribute>
    <a>
      <xsl:attribute name="href">#<xsl:value-of select="." /></xsl:attribute>
      <xsl:attribute name="id"><xsl:value-of select="$ty" /></xsl:attribute>
      <xsl:value-of select="." />
    </a>
  </li>
</xsl:template>

<!-- Template for category summary -->
<xsl:template match="category">
  <h3><xsl:value-of select="name" /></h3>
  <dl>
    <xsl:for-each select="subcategories/subcategory">
      <dd><a><xsl:attribute name="href">#<xsl:value-of select="." /></xsl:attribute>
        <xsl:value-of select="." />
      </a></dd>
    </xsl:for-each>
  </dl>
</xsl:template>

<!-- Template framework for groups -->
<xsl:template match="group">
  <xsl:choose>
    <xsl:when test="$showhidden='false'">
      <xsl:if test="uservisible='true'">
        <xsl:call-template name="grpcontent" />
      </xsl:if>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="grpcontent" />
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- Template for groups in groups -->
<xsl:template match="grouplist//groupreq">
  <xsl:call-template name="ligen">
    <xsl:with-param name="ty">mandatory</xsl:with-param>
  </xsl:call-template>
</xsl:template>

<!-- Template for metapkgs in groups -->
<xsl:template match="grouplist//metapkg">
  <xsl:call-template name="ligen">
    <xsl:with-param name="ty"><xsl:value-of select="@type" /></xsl:with-param>
  </xsl:call-template>
</xsl:template>

<!-- Template for packages in groups -->
<xsl:template match="packagelist//packagereq">
  <li><xsl:attribute name="id"><xsl:value-of select="@type" /></xsl:attribute>
    <a><xsl:attribute name="name"><xsl:value-of select="." /></xsl:attribute></a>
    <xsl:value-of select="." />
    <xsl:if test="@requires!=''">
      　 => <a><xsl:attribute name="href">#<xsl:value-of select="@requires" /></xsl:attribute>
      <xsl:value-of select="@requires" /></a>
    </xsl:if>
  </li>
</xsl:template>

</xsl:stylesheet>
